
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2020-09-04T00:45:31+0200",
 "dirty": false,
 "error": null,
 "full-revisionid": "ecd4996b2b738a9f2c57bb5fef10a1a0ace89151",
 "version": "3.20.1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
